@@ -6,17 +6,12 @@ from typing import Optional
 
 
 @dataclasses.dataclass
-class DeleteSchemaPathParams:
+class DeleteSchemaRequest:
     api_id: str = dataclasses.field(metadata={'path_param': { 'field_name': 'apiID', 'style': 'simple', 'explode': False }})
     revision_id: str = dataclasses.field(metadata={'path_param': { 'field_name': 'revisionID', 'style': 'simple', 'explode': False }})
     version_id: str = dataclasses.field(metadata={'path_param': { 'field_name': 'versionID', 'style': 'simple', 'explode': False }})
     
 
-@dataclasses.dataclass
-class DeleteSchemaRequest:
-    path_params: DeleteSchemaPathParams = dataclasses.field()
-    
-
 @dataclasses.dataclass
 class DeleteSchemaResponse:
     content_type: str = dataclasses.field()
