@@ -6,16 +6,11 @@ from typing import Optional
 
 
 @dataclasses.dataclass
-class GeneratePostmanCollectionPathParams:
+class GeneratePostmanCollectionRequest:
     api_id: str = dataclasses.field(metadata={'path_param': { 'field_name': 'apiID', 'style': 'simple', 'explode': False }})
     version_id: str = dataclasses.field(metadata={'path_param': { 'field_name': 'versionID', 'style': 'simple', 'explode': False }})
     
 
-@dataclasses.dataclass
-class GeneratePostmanCollectionRequest:
-    path_params: GeneratePostmanCollectionPathParams = dataclasses.field()
-    
-
 @dataclasses.dataclass
 class GeneratePostmanCollectionResponse:
     content_type: str = dataclasses.field()
