@@ -7,17 +7,12 @@ from typing import Optional
 
 
 @dataclasses.dataclass
-class GetAPIEndpointPathParams:
+class GetAPIEndpointRequest:
     api_endpoint_id: str = dataclasses.field(metadata={'path_param': { 'field_name': 'apiEndpointID', 'style': 'simple', 'explode': False }})
     api_id: str = dataclasses.field(metadata={'path_param': { 'field_name': 'apiID', 'style': 'simple', 'explode': False }})
     version_id: str = dataclasses.field(metadata={'path_param': { 'field_name': 'versionID', 'style': 'simple', 'explode': False }})
     
 
-@dataclasses.dataclass
-class GetAPIEndpointRequest:
-    path_params: GetAPIEndpointPathParams = dataclasses.field()
-    
-
 @dataclasses.dataclass
 class GetAPIEndpointResponse:
     content_type: str = dataclasses.field()
