@@ -7,16 +7,11 @@ from typing import Optional
 
 
 @dataclasses.dataclass
-class GetSchemaPathParams:
+class GetSchemaRequest:
     api_id: str = dataclasses.field(metadata={'path_param': { 'field_name': 'apiID', 'style': 'simple', 'explode': False }})
     version_id: str = dataclasses.field(metadata={'path_param': { 'field_name': 'versionID', 'style': 'simple', 'explode': False }})
     
 
-@dataclasses.dataclass
-class GetSchemaRequest:
-    path_params: GetSchemaPathParams = dataclasses.field()
-    
-
 @dataclasses.dataclass
 class GetSchemaResponse:
     content_type: str = dataclasses.field()
