@@ -27,7 +27,7 @@ class Requests:
         
         base_url = self._server_url
         
-        url = utils.generate_url(base_url, '/v1/eventlog/{requestID}/generate/postman', request.path_params)
+        url = utils.generate_url(operations.GenerateRequestPostmanCollectionRequest, base_url, '/v1/eventlog/{requestID}/generate/postman', request)
         
         headers = {}
         headers['user-agent'] = f'speakeasy-sdk/{self._language} {self._sdk_version} {self._gen_version}'
@@ -55,7 +55,7 @@ class Requests:
         
         base_url = self._server_url
         
-        url = utils.generate_url(base_url, '/v1/eventlog/{requestID}', request.path_params)
+        url = utils.generate_url(operations.GetRequestFromEventLogRequest, base_url, '/v1/eventlog/{requestID}', request)
         
         headers = {}
         headers['user-agent'] = f'speakeasy-sdk/{self._language} {self._sdk_version} {self._gen_version}'
@@ -89,7 +89,7 @@ class Requests:
         url = base_url.removesuffix('/') + '/v1/eventlog/query'
         
         headers = {}
-        query_params = utils.get_query_params(request.query_params)
+        query_params = utils.get_query_params(operations.QueryEventLogRequest, request)
         headers['user-agent'] = f'speakeasy-sdk/{self._language} {self._sdk_version} {self._gen_version}'
         
         client = self._security_client
